Files
Arthur Eubanks dad32c83e5 [DWP] Stop storing DWPStringPool strings in Buffer (#198678)
When we can just write it out. This decreases peak memory usage of
llvm-dwp on clang debug info from ~800MB to ~350MB without measurable
performance changes.

Also remove DWPStringPool.h to avoid circular headers. It wasn't doing
anything anyway...
2026-05-20 08:12:51 -07:00
..
…